import {select} from 'd3-selection';

import config from 'ui/config';
import * as utils from 'ui/utils';

import {configureStore} from 'ml/store';

import {TEST_PRIMARY_IV_DATA, TEST_CURRENT_TIME_RANGE} from './mock-hydrograph-state';
import {drawCursorSlider} from './cursor-slider';

describe('monitoring-location/components/hydrograph/cursor-slider', () => {
    utils.mediaQuery = jest.fn().mockReturnValue(true);
    config.locationTimeZone = 'America/Chicago';
    const TEST_STATE = {
        hydrographData: {
            primaryIVData: TEST_PRIMARY_IV_DATA,
            currentTimeRAnge: TEST_CURRENT_TIME_RANGE
        },
        hydrographState: {
            graphCursorOffset: 500000
        },
        ui: {
            windowWidth: 1300,
            width: 990
        }
    };

    describe('drawCursorSlider', () => {
        let svg;
        let store;
        beforeEach(() => {
            svg = select('body').append('svg');
            store = configureStore(TEST_STATE);
        });

        afterEach(() => {
            svg.remove();
        });

        it('Creates a cursor slider', () => {
            drawCursorSlider(svg, store);

            const sliderGroup = svg.selectAll('.cursor-slider-group');
            expect(sliderGroup.size()).toBe(1);
            expect(sliderGroup.selectAll('.slider').size()).toBe(1);
        });
    });
});