import {select} from 'd3-selection';

import config from 'ui/config';

import {configureStore} from 'ml/store';

import {drawDataTables} from './data-table';
import {TEST_PRIMARY_IV_DATA, TEST_GW_LEVELS} from './mock-hydrograph-state';

describe('monitoring-location/components/hydrograph/data-table', () => {
    let testDiv;
    let store;

    config.locationTimeZone = 'America/Chicago';

    beforeEach(() => {
        testDiv = select('body').append('div');
    });

    afterEach(() => {
        testDiv.remove();
    });

    it('table with expected data', () => {
        store = configureStore({
            hydrographData: {
                currentTimeRange: {
                    start: 1582560000000,
                    end: 1600620000000
                },
                primaryIVData: TEST_PRIMARY_IV_DATA
            },
            groundwaterLevelData: {
                all: [TEST_GW_LEVELS]
            },
            hydrographState: {
                selectedParameterCode: '72019',
                selectedIVMethodID: '90649'
            }
        });
        drawDataTables(testDiv, store);

        const ivTable = testDiv.select('#iv-table-container').select('table');
        expect(ivTable.select('caption').text()).toBe('Instantaneous value data');
        expect(ivTable.selectAll('tr').size()).toBe(10);
        const gwTable = testDiv.select('#gw-table-container').select('table');
        expect(gwTable.select('caption').text()).toBe('Field visit data');
        expect(gwTable.selectAll('tr').size()).toBe(5);
    });

    it('Renders single IV table if no GW levels', () => {
        store = configureStore({
            hydrographData: {
                currentTimeRange: {
                    start: 1582560900000,
                    end: 1600619400000
                },
                primaryIVData: TEST_PRIMARY_IV_DATA
            },
            groundwaterLevelData: {
                all: []
            },
            hydrographState: {
                selectedParameterCode: '72019',
                selectedIVMethodID: '90649'
            }
        });
        drawDataTables(testDiv, store);

        expect(testDiv.select('#iv-table-container').size()).toBe(1);
        expect(testDiv.select('#gw-table-container').size()).toBe(0);
    });
    it('Renders single GW table if no IV data', () => {
        store = configureStore({
            hydrographData: {
                currentTimeRange: {
                    start: 1582560900000,
                    end: 1600619400000
                }
            },
            groundwaterLevelData: {
                all: [TEST_GW_LEVELS]
            },
            hydrographState: {
                selectedParameterCode: '72019'
            }
        });
        drawDataTables(testDiv, store);

        expect(testDiv.select('#iv-table-container').size()).toBe(0);
        expect(testDiv.select('#gw-table-container').size()).toBe(1);
    });
});
