
import config from 'ui/config.js';

import {link} from 'ui/lib/d3-redux';

import {getSelectedTimeSpan, getInputsForRetrieval, getSelectedParameterCode} from 'ml/selectors/hydrograph-state-selector';

import {clearGraphBrushOffset, setSelectedTimeSpan} from 'ml/store/hydrograph-state';
import {retrieveHydrographData} from 'ml/store/hydrograph-data';

import {showDataIndicators} from './data-indicator';

/*
 * Render a single short cut radio button. Set up the click event handler to update the
 * selectedTimeSpan and fetching the new data. Set up event handler
 * for a change to the selectedTimeSpan in store to update the state of the radio button.
 */
const drawShortcutRadioButton = function(container, store, siteno, agencyCode, {timeSpan, label}) {
    const buttonContainer = container.append('div')
        .attr('class', 'usa-radio');
    buttonContainer.append('input')
        .attr('class', 'usa-radio__input')
        .attr('id', `${timeSpan}-input`)
        .attr('type', 'radio')
        .attr('name', 'time-span')
        .attr('value', timeSpan)
        .on('click', function() {
            if (this.checked) {
                store.dispatch(setSelectedTimeSpan(timeSpan));
                store.dispatch(clearGraphBrushOffset());
                showDataIndicators(true, store);
                store.dispatch(retrieveHydrographData(siteno, agencyCode, getInputsForRetrieval(store.getState())))
                    .then(() => {
                        showDataIndicators(false, store);
                    });

            }
        });
    buttonContainer.append('label')
        .attr('class', 'usa-radio__label')
        .attr('for', `${timeSpan}-input`)
        .text(label);
    buttonContainer.call(link(store, function(thisContainer, selectedTimeSpan) {
        const thisButton = thisContainer.select('input');
        thisButton.property('checked', selectedTimeSpan === thisButton.attr('value'));
    }, getSelectedTimeSpan));
};

const hasIVData = function(parameterCode) {
    return config.ivPeriodOfRecord && parameterCode in config.ivPeriodOfRecord;
};

const hasGWData = function(parameterCode) {
    return config.gwPeriodOfRecord && parameterCode in config.gwPeriodOfRecord;
};

/*
 * Render the shortcut days before radio buttons on container. Set up the appropriate event handlers
 * for user actions and for changes to the selectedTimeSpan.
 * @param {D3 selection} container
 * @param {Redux store} store
 * @param {String} siteno
 */
export const drawTimeSpanShortcutButtons = function(container, store, siteno, agencyCode) {
    const initialParameterCode = getSelectedParameterCode(store.getState());
    const formContainer = container.append('div')
        .attr('class', 'usa-form');
    const ivButtonContainer = formContainer.append('div')
        .attr('class', 'iv-button-container')
        .attr('hidden', hasIVData(initialParameterCode) ? null : true);
    const gwButtonContainer = formContainer.append('div')
        .attr('class', 'gw-button-container')
        .attr('hidden', hasIVData(initialParameterCode) ? true : null);

    config.IV_SHORTCUT_BUTTONS.forEach(shortcut =>
        drawShortcutRadioButton(ivButtonContainer, store, siteno, agencyCode, shortcut));
    config.GW_SHORTCUT_BUTTONS.forEach(shortcut =>
        drawShortcutRadioButton(gwButtonContainer, store, siteno, agencyCode, shortcut));

    formContainer.call(link(store, function(container, selectedParameterCode) {
        if (ivButtonContainer.attr('hidden') && hasIVData(selectedParameterCode)) {
            ivButtonContainer.attr('hidden', null);
            gwButtonContainer.attr('hidden', true);

        } else if (gwButtonContainer.attr('hidden') &&
            !hasIVData(selectedParameterCode) && hasGWData(selectedParameterCode)) {
            ivButtonContainer.attr('hidden', true);
            gwButtonContainer.attr('hidden', null);
        }
    }, getSelectedParameterCode));
};
